@@ -1,22 +1,18 @@
-#ifndef	SHIM_SYS_EPOLL_H
-#define	SHIM_SYS_EPOLL_H
+#ifndef SHIM_SYS_EPOLL_H
+#define SHIM_SYS_EPOLL_H
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#include <stdint.h>
 #include <sys/types.h>
-#include <fcntl.h>
 
-#if defined(__NetBSD__)
-#include <sys/sigtypes.h>
-#elif defined(__OpenBSD__) || defined(__DragonFly__) || defined(__FreeBSD__)
-#include <sys/signal.h>
-#endif
+#include <stdint.h>
+
+#include <fcntl.h>
+#include <signal.h>
 
 #define EPOLL_CLOEXEC O_CLOEXEC
-#define EPOLL_NONBLOCK O_NONBLOCK
 
 enum EPOLL_EVENTS { __EPOLL_DUMMY };
 #define EPOLLIN 0x001
@@ -31,10 +27,10 @@ enum EPOLL_EVENTS { __EPOLL_DUMMY };
 #define EPOLLERR 0x008
 #define EPOLLHUP 0x010
 #define EPOLLRDHUP 0x2000
-#define EPOLLEXCLUSIVE (1U<<28)
-#define EPOLLWAKEUP (1U<<29)
-#define EPOLLONESHOT (1U<<30)
-#define EPOLLET (1U<<31)
+#define EPOLLEXCLUSIVE (1U << 28)
+#define EPOLLWAKEUP (1U << 29)
+#define EPOLLONESHOT (1U << 30)
+#define EPOLLET (1U << 31)
 
 #define EPOLL_CTL_ADD 1
 #define EPOLL_CTL_DEL 2
@@ -52,7 +48,7 @@ struct epoll_event {
 	epoll_data_t data;
 }
 #ifdef __x86_64__
-__attribute__ ((__packed__))
+__attribute__((__packed__))
 #endif
 ;
 
@@ -61,16 +57,10 @@ int epoll_create(int);
 int epoll_create1(int);
 int epoll_ctl(int, int, int, struct epoll_event *);
 int epoll_wait(int, struct epoll_event *, int, int);
-int epoll_pwait(int, struct epoll_event *, int, int, const sigset_t *);
+int epoll_pwait(int, struct epoll_event *, int, int, sigset_t const *);
 
 
-#ifndef SHIM_SYS_SHIM_HELPERS
-#define SHIM_SYS_SHIM_HELPERS
-#include <unistd.h> /* IWYU pragma: keep */
-
-extern int epoll_shim_close(int);
-#define close epoll_shim_close
-#endif
+#include <epoll-shim/detail/common.h>
 
 
 #ifdef __cplusplus
