@@ -5,8 +5,8 @@
 extern "C" {
 #endif
 
-#include <time.h>
 #include <fcntl.h>
+#include <time.h>
 
 #define TFD_NONBLOCK O_NONBLOCK
 #define TFD_CLOEXEC O_CLOEXEC
@@ -17,23 +17,13 @@ extern "C" {
 struct itimerspec;
 
 int timerfd_create(int, int);
-int timerfd_settime(int, int, const struct itimerspec *, struct itimerspec *);
+int timerfd_settime(int, int, struct itimerspec const *, struct itimerspec *);
 int timerfd_gettime(int, struct itimerspec *);
 
 
-#ifndef SHIM_SYS_SHIM_HELPERS
-#define SHIM_SYS_SHIM_HELPERS
-#include <unistd.h> /* IWYU pragma: keep */
-
-extern int epoll_shim_close(int);
-#define close epoll_shim_close
-#endif
-
-#ifndef SHIM_SYS_SHIM_HELPERS_READ
-#define SHIM_SYS_SHIM_HELPERS_READ
-extern ssize_t epoll_shim_read(int, void *, size_t);
-#define read epoll_shim_read
-#endif
+#include <epoll-shim/detail/common.h>
+#include <epoll-shim/detail/poll.h>
+#include <epoll-shim/detail/read.h>
 
 
 #ifdef __cplusplus
